==> QLC%2B_4.12.6.tar.gz: qlcplus-QLC-_4.12.6/plugins/E1.31/E131_ca_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca_ES">
<context>
    <name>ConfigureE131</name>
    <message>
        <location filename="configuree131.ui" line="33"/>
        <source>Configure E1.31 Plugin</source>
        <translation>Configurar plugin E1.31</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="43"/>
        <source>Universes Configuration</source>
        <translation>Configuració d&apos;Universos</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="56"/>
        <source>Interface</source>
        <translation>Interficie</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="66"/>
        <source>Multicast</source>
        <translation>Multicast</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="71"/>
        <source>IP Address</source>
        <translation>Direcció IP</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="76"/>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="81"/>
        <source>E1.31 Universe</source>
        <translation>Univers E1.31</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="86"/>
        <source>Transmission Mode</source>
        <translation>Mode de transmissió</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="91"/>
        <source>Priority</source>
        <translation>Prioritat</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="61"/>
        <source>Universe</source>
        <translation>Univers</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="86"/>
        <source>Inputs</source>
        <translation>Entrades</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="92"/>
        <source>Outputs</source>
        <translation>Sortides</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="176"/>
        <source>Full</source>
        <translation>Complet</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="177"/>
        <source>Partial</source>
        <translation>Parcial</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="185"/>
        <source>%1 - min, %2 - default, %3 - max</source>
        <translation>%1 - min, %2 - defecte, %3 . max</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="216"/>
        <source>Invalid IP</source>
        <translation>IP invàlida</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="216"/>
        <source>%1 is not a valid IP.
Please fix it before confirming.</source>
        <translation>%1 no es una IP vàlida.
Si us plau arreglar-ho abans de continuar.</translation>
    </message>
</context>
<context>
    <name>E131Plugin</name>
    <message>
        <location filename="e131plugin.cpp" line="93"/>
        <source>This plugin provides DMX output for devices supporting the E1.31 communication protocol.</source>
        <translation>Aquest plugin proveeix sortida DMX per dispositius que suporten el protocol de comunicació E1.31.</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="140"/>
        <source>Output</source>
        <translation>Sortida</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="144"/>
        <location filename="e131plugin.cpp" line="284"/>
        <source>Status: Not open</source>
        <translation>Estat: No obert</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="147"/>
        <location filename="e131plugin.cpp" line="287"/>
        <source>Status: Open</source>
        <translation>Estat: Obert</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="149"/>
        <source>Packets sent: </source>
        <translation>Paquets enviats:</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="280"/>
        <source>Input</source>
        <translation>Entrada</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="289"/>
        <source>Packets received: </source>
        <translation>Paquets rebuts:</translation>
    </message>
</context>
</TS>

==> QLC%2B_4.14.0.tar.gz: qlcplus-QLC-_4.14.0/plugins/E1.31/E131_ca_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca_ES">
<context>
    <name>ConfigureE131</name>
    <message>
        <location filename="configuree131.ui" line="33"/>
        <source>Configure E1.31 Plugin</source>
        <translation>Configurar plugin E1.31</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="43"/>
        <source>Universes Configuration</source>
        <translation>Configuració d&apos;Universos</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="56"/>
        <source>Interface</source>
        <translation>Interficie</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="66"/>
        <source>Multicast</source>
        <translation>Multicast</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="71"/>
        <source>IP Address</source>
        <translation>Direcció IP</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="76"/>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="81"/>
        <source>E1.31 Universe</source>
        <translation>Univers E1.31</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="86"/>
        <source>Transmission Mode</source>
        <translation>Mode de transmissió</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="91"/>
        <source>Priority</source>
        <translation>Prioritat</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="101"/>
        <source>Seconds to wait for an interface to be ready</source>
        <translation>Segons a esperar que estigui preparada una interfície</translation>
    </message>
    <message>
        <location filename="configuree131.ui" line="61"/>
        <source>Universe</source>
        <translation>Univers</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="99"/>
        <source>Inputs</source>
        <translation>Entrades</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="105"/>
        <source>Outputs</source>
        <translation>Sortides</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="189"/>
        <source>Full</source>
        <translation>Complet</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="190"/>
        <source>Partial</source>
        <translation>Parcial</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="198"/>
        <source>%1 - min, %2 - default, %3 - max</source>
        <translation>%1 - min, %2 - defecte, %3 . max</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="245"/>
        <source>Invalid IP</source>
        <translation>IP invàlida</translation>
    </message>
    <message>
        <location filename="configuree131.cpp" line="245"/>
        <source>%1 is not a valid IP.
Please fix it before confirming.</source>
        <translation>%1 no es una IP vàlida.
Si us plau arreglar-ho abans de continuar.</translation>
    </message>
</context>
<context>
    <name>E131Plugin</name>
    <message>
        <location filename="e131plugin.cpp" line="97"/>
        <source>This plugin provides DMX output for devices supporting the E1.31 communication protocol.</source>
        <translation>Aquest plugin proveeix sortida DMX per dispositius que suporten el protocol de comunicació E1.31.</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="144"/>
        <source>Output</source>
        <translation>Sortida</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="148"/>
        <location filename="e131plugin.cpp" line="287"/>
        <source>Status: Not open</source>
        <translation>Estat: No obert</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="151"/>
        <location filename="e131plugin.cpp" line="290"/>
        <source>Status: Open</source>
        <translation>Estat: Obert</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="153"/>
        <source>Packets sent: </source>
        <translation>Paquets enviats: </translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="283"/>
        <source>Input</source>
        <translation>Entrada</translation>
    </message>
    <message>
        <location filename="e131plugin.cpp" line="292"/>
        <source>Packets received: </source>
        <translation>Paquets rebuts: </translation>
    </message>
</context>
</TS>
